@@ -11,7 +11,8 @@ typedef enum
 {
 	CL_STYLE_CLASSIC = 0,
 	CL_STYLE_GLOSSY = 1,
-	CL_NUM_STYLES = 2
+	CL_STYLE_INVERTED = 2,
+	CL_NUM_STYLES = 3
 } ClearlooksStyles;
 
 
@@ -136,6 +137,8 @@ typedef struct
 	boolean is_default;
 	boolean ltr;
 	boolean enable_glow;
+
+	gfloat  radius;
 	
 	ClearlooksStateType state_type;
 	
@@ -157,7 +160,6 @@ typedef struct
 typedef struct
 {
 	ClearlooksOrientation orientation;
-	ClearlooksProgressBarStyle style;
 	boolean pulsing;
 	float value;
 } ProgressBarParameters;
@@ -173,7 +175,7 @@ typedef struct
 	ClearlooksGapSide gap_side;
 	int gap_x;
 	int gap_width;
-	CairoColor *border;
+	CairoColor *border; /* maybe changes this to some other hint ... */
 } FrameParameters;
 
 typedef struct
@@ -194,7 +196,7 @@ typedef struct
 
 typedef struct
 {
-	ClearlooksOrder order;
+	ClearlooksOrder order; /* XXX: rename to position */
 	boolean         resizable;
 } ListViewHeaderParameters;
 
@@ -202,7 +204,6 @@ typedef struct
 {
 	CairoColor         color;
 	ClearlooksJunction junction;       /* On which sides the slider junctions */
-	ClearlooksStepper  steppers;       /* The visible steppers */
 	boolean            horizontal;
 	boolean            has_color;
 } ScrollBarParameters;
@@ -218,12 +219,6 @@ typedef struct
 	ClearlooksStepper stepper;         /* Which stepper to draw */
 } ScrollBarStepperParameters;
 
-typedef struct
-{
-	ClearlooksArrowType type;
-	ClearlooksDirection direction;
-} ArrowParameters;
-
 typedef struct
 {
 	ClearlooksWindowEdge edge;
@@ -241,6 +236,11 @@ typedef struct
 	boolean              in_menu;
 } CheckboxParameters;
 
+typedef struct
+{
+	ClearlooksArrowType type;
+	ClearlooksDirection direction;
+} ArrowParameters;
 
 struct _ClearlooksStyleFunctions
 {
@@ -294,6 +294,7 @@ struct _ClearlooksStyleFunctions
 	                               int x, int y, int width, int height);
 					   
 	void (*draw_inset)            (cairo_t				*cr,
+                                   const ClearlooksColors		*colors,
 	                               int width, int height,
 	                               double radius, uint8 corners);
 
@@ -337,6 +338,16 @@ struct _ClearlooksStyleFunctions
 	                               const WidgetParameters		*widget,
 	                               int x, int y, int width, int height);
 
+	void (*draw_menubaritem)      (cairo_t				*cr,
+	                               const ClearlooksColors		*colors,
+	                               const WidgetParameters		*widget,
+	                               int x, int y, int width, int height);
+
+	void (*draw_selected_cell)    (cairo_t				*cr,
+	                               const ClearlooksColors		*colors,
+	                               const WidgetParameters		*widget,
+	                               int x, int y, int width, int height);
+
 	void (*draw_scrollbar_stepper) (cairo_t				*cr,
 	                                const ClearlooksColors		*colors,
 	                                const WidgetParameters		*widget,
@@ -372,17 +383,17 @@ struct _ClearlooksStyleFunctions
 	                               const HandleParameters		*handle,
 	                               int x, int y, int width, int height);
 
-	void (*draw_arrow)            (cairo_t				*cr,
-	                               const ClearlooksColors		*colors,
-	                               const WidgetParameters		*widget,
-	                               const ArrowParameters		*arrow,
-	                               int x, int y, int width, int height);
-
 	void (*draw_resize_grip)      (cairo_t				*cr,
 	                               const ClearlooksColors		*colors,
 	                               const WidgetParameters		*widget,
 	                               const ResizeGripParameters	*grip,
 	                               int x, int y, int width, int height);
+
+	void (*draw_arrow)      (cairo_t				*cr,
+					                       const ClearlooksColors          *colors,
+					                       const WidgetParameters          *widget,
+					                       const ArrowParameters           *arrow,
+					                       int x, int y, int width, int height);
 	                               
 	void (*draw_checkbox)         (cairo_t				*cr,
 	                               const ClearlooksColors		*colors,
@@ -399,6 +410,8 @@ struct _ClearlooksStyleFunctions
 	/* Style internal functions */
 	/* XXX: Only used by slider_button, inline it? */
 	void (*draw_shadow)           (cairo_t				*cr,
+                                   const ClearlooksColors		*colors,
+	                               gfloat                            radius,
 	                               int				 width,
 	                               int				 height);
 
@@ -407,9 +420,10 @@ struct _ClearlooksStyleFunctions
 	                               const WidgetParameters		*widget,
 	                               int x, int y, int width, int height);
 
-	void (*draw_gripdots)         (cairo_t *cr, int x, int y,
-                                       int width, int height, int xr, int yr,
-                                       float contrast);
+	void (*draw_gripdots)         (cairo_t *cr,
+                                    const ClearlooksColors *colors, int x, int y,
+                                    int width, int height, int xr, int yr,
+                                    float contrast);
 };
 
 
