@@ -153,64 +153,55 @@ redmond_draw_check (GtkStyle * style,
  
   cr = ge_gdk_drawable_to_cairo (window, area);
 
-  if (CHECK_DETAIL (detail, "check"))	/* Menu item */
+  if (CHECK_DETAIL (detail, "check") && /* Special case for menu items. */
+     (shadow != GTK_SHADOW_ETCHED_IN))
     {
-      /* check boxes in menu don't actually draw box, only the check mark,
-       * which use the text color 
-       */
       if (shadow == GTK_SHADOW_IN)
-	{
-	  do_redmond_draw_check (cr, &redmond_style->color_cube.text[state], x + 3, y + 3,
-			 width - 4, height - 4);
-	}
+        do_redmond_draw_check (cr, &redmond_style->color_cube.text[GTK_STATE_NORMAL],
+                               x + 2, y + 2, width - 4, height - 4);
     }
   else
     {
-      switch (state)
-	{
-	case GTK_STATE_NORMAL:
-	case GTK_STATE_PRELIGHT:
-          if (GE_IS_TOGGLE_BUTTON(widget) && TOGGLE_BUTTON(widget)->inconsistent)
-            do_redmond_draw_masked_fill (cr, &redmond_style->hatch_mask, 
-                                              &redmond_style->color_cube.bg[GTK_STATE_NORMAL],
-                                              &redmond_style->color_cube.light[GTK_STATE_NORMAL],
-                                              x, y, width, height);
-	  else
+      if (state == GTK_STATE_ACTIVE || state == GTK_STATE_INSENSITIVE)
+      {
+        ge_cairo_set_color(cr, &redmond_style->color_cube.bg[GTK_STATE_NORMAL]);
+
+        cairo_rectangle(cr, x, y, width - 1, height - 1);
+
+        cairo_fill(cr);
+      }
+      else
+      {
+        /* Draw stipples for inconsistent checkboxes. */
+        if (shadow == GTK_SHADOW_ETCHED_IN)
           {
+            do_redmond_draw_masked_fill (cr, &redmond_style->hatch_mask, 
+                                             &redmond_style->color_cube.bg[GTK_STATE_NORMAL],
+                                             &redmond_style->color_cube.light[GTK_STATE_NORMAL],
+                                             x, y, width, height);
+          }
+        else
+          {
+            /* ignore PRELIGHT state ... */
             ge_cairo_set_color(cr, &redmond_style->color_cube.base[GTK_STATE_NORMAL]);
 
             cairo_rectangle(cr, x, y, width - 1, height - 1);
 
             cairo_fill(cr);
           }
+      }
 
-	  break;
-	default:
-          ge_cairo_set_color(cr, &redmond_style->color_cube.bg[GTK_STATE_NORMAL]);
-
-          cairo_rectangle(cr, x, y, width - 1, height - 1);
-
-          cairo_fill(cr);
-
-	}
- 
-      if ((shadow == GTK_SHADOW_IN) || 
-          (GE_IS_TOGGLE_BUTTON(widget) && 
-           TOGGLE_BUTTON(widget)->inconsistent))
-	{
-	  if ((state == GTK_STATE_INSENSITIVE) || 
-              (GE_IS_TOGGLE_BUTTON(widget) && 
-               TOGGLE_BUTTON(widget)->inconsistent))
-            {
-	      do_redmond_draw_check (cr, &redmond_style->color_cube.fg[GTK_STATE_INSENSITIVE],
-			             x + 2, y + 2, width - 4, height - 4);
-            }
-	  else
-            {
-	      do_redmond_draw_check (cr, &redmond_style->color_cube.fg[GTK_STATE_NORMAL],
-			             x + 2, y + 2, width - 4, height - 4);
-            }
-	}
+      if ((shadow == GTK_SHADOW_ETCHED_IN) || (state == GTK_STATE_INSENSITIVE))
+        {
+          /* force insensitive color for inconsistent checkboxes */
+          do_redmond_draw_check (cr, &redmond_style->color_cube.fg[GTK_STATE_INSENSITIVE],
+                                 x + 2, y + 2, width - 4, height - 4);
+        }
+      else if (shadow == GTK_SHADOW_IN)
+        {
+          do_redmond_draw_check (cr, &redmond_style->color_cube.fg[GTK_STATE_NORMAL],
+                                 x + 2, y + 2, width - 4, height - 4);
+        }
  
       redmond_draw_shadow (style, window, GTK_STATE_NORMAL, GTK_SHADOW_IN,
 			area, widget, detail, x, y, width, height);
@@ -251,99 +242,90 @@ redmond_draw_option (GtkStyle * style,
              gint height)
 {
   RedmondStyle *redmond_style = REDMOND_STYLE (style);
- 
   gint center_x;
   gint center_y;
   gint radius;
-
+ 
   cairo_t *cr;
 
   CHECK_ARGS
   SANITIZE_SIZE
- 
+
   center_x = x + floor(width/2);
   center_y = y + floor(height/2);
   radius = floor(MIN(width, height)/2) + 1;
 
   cr = ge_gdk_drawable_to_cairo (window, area);
 
-  if (CHECK_DETAIL (detail, "option"))	/* Menu item */
+  if (CHECK_DETAIL (detail, "check") && /* Special case for menu items. */
+     (shadow != GTK_SHADOW_ETCHED_IN))
     {
-      /* check boxes in menu don't actually draw box, only the mark,
-       * which use the text color 
-       */
       if (shadow == GTK_SHADOW_IN)
-      {
-        ge_cairo_set_color(cr, &redmond_style->color_cube.text[state]);	
-	cairo_arc(cr, center_x, center_y, radius*0.38, 0, 2 * M_PI);
-        cairo_fill(cr);
-      }
+        {
+          ge_cairo_set_color(cr, &redmond_style->color_cube.text[GTK_STATE_NORMAL]);
+          cairo_arc(cr, center_x, center_y, radius*0.38, 0, 2 * G_PI);
+          cairo_fill(cr);
+        }
     }
   else
     {
-      gboolean inconsistent;
+      do_redmond_draw_simple_circle (cr, &redmond_style->color_cube.dark[GTK_STATE_NORMAL],
+                                     &redmond_style->color_cube.light[GTK_STATE_NORMAL],
+                                     center_x, center_y, radius);
 
-  do_redmond_draw_simple_circle (cr, &redmond_style->color_cube.dark[GTK_STATE_NORMAL],
-				&redmond_style->color_cube.light[GTK_STATE_NORMAL],
-					center_x, 
-					center_y, 
-					radius);
+      do_redmond_draw_simple_circle (cr, &redmond_style->black_border[GTK_STATE_NORMAL],
+                                     &redmond_style->color_cube.bg[GTK_STATE_NORMAL],
+                                     center_x, center_y, radius - 1);
 
-  do_redmond_draw_simple_circle (cr, &redmond_style->black_border[GTK_STATE_NORMAL],
-				&redmond_style->color_cube.bg[GTK_STATE_NORMAL],
-					center_x, 
-					center_y, 
-					radius - 1);
+      if (state == GTK_STATE_ACTIVE || state == GTK_STATE_INSENSITIVE)
+      {
+        ge_cairo_set_color (cr, &redmond_style->color_cube.bg[GTK_STATE_NORMAL]);
 
-      inconsistent = (GE_IS_TOGGLE_BUTTON(widget) && gtk_toggle_button_get_inconsistent(TOGGLE_BUTTON(widget)));
-      inconsistent |= (GE_IS_CELL_RENDERER_TOGGLE(widget) && ge_cell_renderer_toggle_get_inconsistent (widget));
-      inconsistent |= (CHECK_DETAIL(detail, "cellradio") && (shadow == GTK_SHADOW_ETCHED_IN));
- 
-      switch (state)
-	{
-	case GTK_STATE_NORMAL:
-	case GTK_STATE_PRELIGHT:
-          if (inconsistent)
+        cairo_arc  (cr, center_x, center_y,  radius - 2, 0, 2*G_PI);
+
+        cairo_fill (cr);
+      }
+      else
+      {
+        /* Draw stipples for inconsistent checkboxes. */
+        if (shadow == GTK_SHADOW_ETCHED_IN)
           {
-             cairo_t *tmp = ge_gdk_drawable_to_cairo (window, area);
+            cairo_save (cr);
+            cairo_arc  (cr, center_x, center_y,  radius - 2, 0, 2*G_PI);
+            cairo_clip (cr);
 
-            cairo_arc(tmp, center_x, center_y,  radius - 2, 0, 2*M_PI);
-            cairo_clip(tmp);
+            do_redmond_draw_masked_fill (cr, &redmond_style->hatch_mask, 
+                                             &redmond_style->color_cube.bg[GTK_STATE_NORMAL],
+                                             &redmond_style->color_cube.light[GTK_STATE_NORMAL],
+                                             x, y, width, height);
 
-            do_redmond_draw_masked_fill (tmp, &redmond_style->hatch_mask, 
-                                              &redmond_style->color_cube.bg[GTK_STATE_NORMAL],
-                                              &redmond_style->color_cube.light[GTK_STATE_NORMAL],
-                                              x, y, width, height);
-	    cairo_destroy(tmp);
-         }
-          else
-          {
-            ge_cairo_set_color(cr, &redmond_style->color_cube.base[GTK_STATE_NORMAL]);
-            cairo_arc(cr, center_x, center_y, radius - 2, 0, 2 * M_PI);
-            cairo_fill(cr);
+            cairo_restore (cr);
           }
-	  break;
-	default:
-            ge_cairo_set_color(cr, &redmond_style->color_cube.bg[GTK_STATE_NORMAL]);
-            cairo_arc(cr, center_x, center_y, radius - 2, 0, 2 * M_PI);
-            cairo_fill(cr);
-	}
+        else
+          {
+            /* ignore PRELIGHT state ... */
+            ge_cairo_set_color (cr, &redmond_style->color_cube.base[GTK_STATE_NORMAL]);
 
-      if ((shadow == GTK_SHADOW_IN) || inconsistent)
-	{
-           if ((state==GTK_STATE_INSENSITIVE) || inconsistent)
-           {
-             ge_cairo_set_color(cr, &redmond_style->color_cube.fg[GTK_STATE_INSENSITIVE]);
-           }
-           else
-           {
-             ge_cairo_set_color(cr, &redmond_style->color_cube.text[GTK_STATE_NORMAL]);	
-           }
+            cairo_arc  (cr, center_x, center_y,  radius - 2, 0, 2*G_PI);
 
-           cairo_arc(cr, center_x, center_y, radius*0.38, 0, 2 * M_PI);
-           cairo_fill(cr);
-	}
-     }
+            cairo_fill (cr);
+          }
+      }
+
+      if ((shadow == GTK_SHADOW_ETCHED_IN) || (state == GTK_STATE_INSENSITIVE))
+        {
+          ge_cairo_set_color(cr, &redmond_style->color_cube.text[GTK_STATE_NORMAL]);
+          cairo_arc(cr, center_x, center_y, radius*0.38, 0, 2 * G_PI);
+          cairo_fill(cr);
+        }
+      else if (shadow == GTK_SHADOW_IN)
+        {
+          /* force insensitive color for inconsistent checkboxes */
+          ge_cairo_set_color(cr, &redmond_style->color_cube.fg[GTK_STATE_INSENSITIVE]);
+          cairo_arc(cr, center_x, center_y, radius*0.38, 0, 2 * G_PI);
+          cairo_fill(cr);
+        }
+    }
 
      cairo_destroy(cr);
 }
@@ -508,8 +490,7 @@ redmond_draw_shadow (GtkStyle * style,
 	   */
            cairo_set_line_width (cr, 1);
            ge_cairo_set_color(cr, &redmond_style->black_border[state_type]);	
-           cairo_rectangle(cr, x + 0.5, y + 0.5, width - 1, height - 1);
-           cairo_stroke(cr);
+           ge_cairo_stroke_rectangle(cr, x + 0.5, y + 0.5, width - 1, height - 1);
 	}
       else if (((CHECK_DETAIL (detail, "vscrollbar"))
 		|| (CHECK_DETAIL (detail, "hscrollbar"))
@@ -521,8 +502,7 @@ redmond_draw_shadow (GtkStyle * style,
 	   */
            cairo_set_line_width (cr, 1);
            ge_cairo_set_color(cr, &redmond_style->color_cube.dark[state_type]);	
-           cairo_rectangle(cr, x + 0.5, y + 0.5, width - 1, height - 1);
-           cairo_stroke(cr);
+           ge_cairo_stroke_rectangle(cr, x + 0.5, y + 0.5, width - 1, height - 1);
 	}
       else if (((CHECK_DETAIL (detail, "entry"))
 		|| (CHECK_DETAIL (detail, "frame")))
@@ -759,7 +739,7 @@ redmond_draw_combobox_button (GtkStyle * style,
 
        cr = ge_gdk_drawable_to_cairo (window, area);
  
-        do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
+        ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
 				          x, y + 2, width - 2, height - 4);
       cairo_destroy(cr);
 
@@ -789,8 +769,7 @@ redmond_draw_combobox_button (GtkStyle * style,
                 parent_state = GTK_STATE_NORMAL;
 
 	      gdk_draw_rectangle (window,
-		  	          widget->parent->style->
-			          base_gc[GTK_WIDGET_STATE (widget->parent)],
+		  	          parent_style->base_gc[parent_state],
 			          TRUE, x + 2, y, width + 2, height);
             }
           else
@@ -858,7 +837,7 @@ redmond_draw_combobox_button (GtkStyle * style,
  
       cr = ge_gdk_drawable_to_cairo (window, area);
 
-      do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
+      ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
 				          x + 2, y + 2, width - 2, height - 4);
 
       cairo_destroy(cr);
@@ -924,7 +903,7 @@ redmond_draw_spinbutton_stepper (GtkStyle * style,
 			    &spin_area, widget, detail, x - 2, y,
 			    width + 2, height + 2);
           cr = ge_gdk_drawable_to_cairo (window, area);
-	  do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type), 
+	  ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type), 
 					      x, y + 2, width - 2, height - 2);
           cairo_destroy(cr);
 	  gtk_paint_shadow (style, window, state_type, shadow_type,
@@ -940,7 +919,7 @@ redmond_draw_spinbutton_stepper (GtkStyle * style,
 			    &spin_area, widget, detail, x - 2, y - 2,
 			    width + 2, height + 2);
           cr = ge_gdk_drawable_to_cairo (window, area);
-	  do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
+	  ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
 					      x, y, width - 2, height - 2);
           cairo_destroy(cr);
 	  gtk_paint_shadow (style, window, state_type, shadow_type,
@@ -959,7 +938,7 @@ redmond_draw_spinbutton_stepper (GtkStyle * style,
 			    &spin_area, widget, detail, x, y,
 			    width + 4, height + 2);
           cr = ge_gdk_drawable_to_cairo (window, area);
-	  do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type), 
+	  ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type), 
 					      x + 2, y + 2, width - 2, height - 2);
           cairo_destroy(cr);
 	  gtk_paint_shadow (style, window, state_type, shadow_type,
@@ -975,7 +954,7 @@ redmond_draw_spinbutton_stepper (GtkStyle * style,
 			    &spin_area, widget, detail, x, y - 2,
 			    width + 4, height + 2);
           cr = ge_gdk_drawable_to_cairo (window, area);
-	  do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type), 
+	  ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type), 
 					      x + 2, y, width - 2, height - 2);
           cairo_destroy(cr);
 	  gtk_paint_shadow (style, window, state_type, shadow_type,
@@ -1050,7 +1029,7 @@ redmond_draw_box (GtkStyle * style,
        */
       cr = ge_gdk_drawable_to_cairo (window, area);
 
-      do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
+      ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, GTK_STATE_NORMAL),
                                     x, y, width, height);
       if (GE_IS_HSCALE (widget))
 	{
@@ -1237,7 +1216,7 @@ redmond_draw_box (GtkStyle * style,
         }
   
       cr = ge_gdk_drawable_to_cairo (window, area);
-      do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
+      ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
 					  x, y, width, height);
  
       /* If this is a menu embedded in the gnome-panel, we don't
@@ -1277,7 +1256,7 @@ redmond_draw_box (GtkStyle * style,
  
       cr = ge_gdk_drawable_to_cairo (window, area);
 
-      do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
+      ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
 					  x, y, width, height);
 		 			  
       if ((!GE_IS_MENU(GTK_MENU_ITEM(widget)->submenu)) || 
@@ -1312,7 +1291,7 @@ redmond_draw_box (GtkStyle * style,
 	state_type = GTK_STATE_NORMAL;
 
       cr = ge_gdk_drawable_to_cairo (window, area);
-      do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, GTK_STATE_SELECTED),
+      ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, GTK_STATE_SELECTED),
                                     x, y, width, height);
       cairo_destroy(cr);
     }
@@ -1334,7 +1313,7 @@ redmond_draw_box (GtkStyle * style,
       redmond_draw_spinbutton_stepper (style, window, state_type, shadow_type, area,
 			       widget, detail, x, y, width, height);
     }
-  else if (GE_IS_TOGGLE_BUTTON(widget) && (TOGGLE_BUTTON(widget)->active))
+  else if (GE_IS_TOGGLE_BUTTON (widget) && (shadow_type == GTK_SHADOW_IN))
     {
       gint pointer_x, pointer_y;
       GdkModifierType pointer_mask;
@@ -1349,7 +1328,7 @@ redmond_draw_box (GtkStyle * style,
 	  (pointer_y < (widget->allocation.y +
 	                widget->allocation.height)))
         {
-          do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
+          ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
                                         x, y, width, height);
         }
       else 
@@ -1369,7 +1348,7 @@ redmond_draw_box (GtkStyle * style,
       /* default box apearance */
       cr = ge_gdk_drawable_to_cairo (window, area);
 
-      do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
+      ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
                                     x, y, width,height);
       cairo_destroy(cr);
       redmond_draw_shadow (style, window, state_type, shadow_type, area,
@@ -1465,7 +1444,7 @@ redmond_draw_slider (GtkStyle * style,
   if ((CHECK_DETAIL (detail, "hscale")) || (CHECK_DETAIL (detail, "vscale")))
     {
       cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
-      do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
+      ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
                                     x, y, width, height);
  
       cairo_destroy(cr);
@@ -1513,11 +1492,13 @@ redmond_draw_extension (GtkStyle * style,
   SANITIZE_SIZE
  
   cr = ge_gdk_drawable_to_cairo (window, area);
-  do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, GTK_STATE_NORMAL),
+  ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, GTK_STATE_NORMAL),
                                 x, y, width, height);
   switch (shadow_type)
     {
     case GTK_SHADOW_NONE:
+      /* need to destroy the cairo context */
+      cairo_destroy (cr);
       return;
     case GTK_SHADOW_IN:
       color1 = &redmond_style->color_cube.dark[state_type];
@@ -1555,7 +1536,7 @@ redmond_draw_extension (GtkStyle * style,
       switch (gap_side)
 	{
 	case GTK_POS_TOP:
-	  do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
+	  ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
                                         x + style->xthickness, 
                                         y,
                                         width - (2 * style->xthickness),
@@ -1575,7 +1556,7 @@ redmond_draw_extension (GtkStyle * style,
 			 y + height - 2);
 	  break;
 	case GTK_POS_BOTTOM:
-	  do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
+	  ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
                                         x + style->xthickness, 
                                         y + style->ythickness,
                                         width - (2 * style->xthickness),
@@ -1596,7 +1577,7 @@ redmond_draw_extension (GtkStyle * style,
 			 y + 1);
 	  break;
 	case GTK_POS_LEFT:
-	  do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
+	  ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
                                         x,
                                         y + style->ythickness,
                                         width - (style->xthickness),
@@ -1615,7 +1596,7 @@ redmond_draw_extension (GtkStyle * style,
 			 y + height - 2);
 	  break;
 	case GTK_POS_RIGHT:
-	  do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
+	  ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type),
                                         x + style->xthickness,
                                         y + style->ythickness,
                                         width - (style->xthickness),
@@ -1668,7 +1649,8 @@ redmond_draw_handle (GtkStyle * style,
   
   if (GE_IS_BONOBO_DOCK_ITEM_GRIP(widget) && 
      (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL) && 
-      orientation == (GTK_ORIENTATION_HORIZONTAL))
+     (orientation == (GTK_ORIENTATION_HORIZONTAL)) &&
+     (widget->parent != NULL))
   {
     x = widget->parent->allocation.width - widget->allocation.width;
     y = widget->parent->allocation.height - widget->allocation.height;
@@ -1679,7 +1661,7 @@ redmond_draw_handle (GtkStyle * style,
   }
   
   cr = ge_gdk_drawable_to_cairo (window, area);
-  do_redmond_draw_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type), 
+  ge_cairo_pattern_fill (cr, DEFAULT_BACKGROUND_PATTERN(redmond_style, state_type), 
                                 x, y, width, height);
  
   if (widget && !(GE_IS_PANED (widget)))
